.. _oa_fasta:

The :program:`fasta` command
============================


The :ref:`organelle assembler <oa>`'s :program:`fasta` is a simple utility command that outputs
all the stems of the compacted assembly graph as a collection of sequences in fasta format. 


command prototype
-----------------

.. program:: oa fasta

.. code-block:: none

    usage: oa fasta [-h]
                    index [<output>]

.. include:: ../options/positional.txt


optional arguments
------------------

General option
++++++++++++++

.. option::    -h, --help

                           show the help message and exit

